@@ -32,7 +32,10 @@ if CONFIG["CIRCE_TRANSFORMATIONS_MODULE"]:
         if isfunction(getattr(transformations_module, transformation_name)) or isclass(
             getattr(transformations_module, transformation_name)
         ):
-            sign = signature(getattr(transformations_module, transformation_name))
+            try:
+                sign = signature(getattr(transformations_module, transformation_name))
+            except ValueError:
+                continue
             params = []
             for param in sign.parameters:
                 params.append(param)
